#line 2 "gengtype-lex.c"

#line 4 "gengtype-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 49
#define YY_END_OF_BUFFER 50
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[445] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   50,   36,
       36,   33,   45,   36,   45,   34,   36,   36,   34,   34,
       34,   34,   34,   31,   10,   10,   31,   29,   31,   31,
       31,   20,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   10,   31,   41,   39,   46,   46,    0,    0,    0,
       37,    0,    0,    0,   38,   32,   34,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   34,   34,   34,   34,
       34,   10,    0,   25,    0,    0,    0,    0,    9,   20,
       24,    0,    0,    0,    0,    0,    0,    0,    0,   26,

       11,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   10,    0,    0,    0,    0,
       42,   44,   43,    0,   35,    0,    0,    0,    0,    0,
        0,   34,   34,   34,   34,   34,   34,   27,   28,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   30,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   34,   34,   34,   34,   34,   34,
        0,    0,    0,   13,    0,   14,    0,    0,    0,    0,
       22,   22,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   48,    0,    0,    0,    0,    0,    0,
        0,   34,   34,   34,   34,   34,   34,    0,    0,    0,
        0,    0,   17,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   34,
       34,   34,   34,   34,    3,    0,    0,    0,    0,   12,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   15,    0,    0,    0,
        0,    0,    0,    0,   34,    4,    5,    2,   34,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   16,
        0,    0,    0,    0,   34,    1,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   22,   22,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   34,   34,   34,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       21,    0,    0,    0,    0,    0,    0,   34,    7,    6,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   18,
        0,    0,    0,   34,    0,    0,    0,    0,    0,    0,
        0,    0,   19,    0,    0,   47,   34,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   34,    0,    0,

        0,    0,    0,    0,    0,    0,   34,    0,   24,   24,
        0,    0,    0,    0,    0,    0,    0,   34,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    8,
        0,   23,    0,    0,    0,    0,    0,   40,    0,    0,
        0,    0,    0,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    6,    1,    7,    8,
        9,   10,    1,    6,    6,   11,   12,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,    6,    6,    6,
        6,    6,    1,    1,   14,   15,   16,   17,   18,   19,
       20,   21,   22,   23,   23,   24,   25,   26,   27,   28,
       23,   29,   30,   31,   32,   33,   34,   23,   35,   23,
       36,   37,   38,    1,   39,    1,   40,   41,   42,   43,

       44,   45,   46,   47,   48,   49,   49,   50,   51,   52,
       53,   54,   49,   55,   56,   57,   58,   59,   49,   60,
       61,   62,    6,    6,    6,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[63] =
    {   0,
        1,    2,    3,    1,    1,    1,    1,    1,    4,    5,
        1,    1,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    8,    1,    1,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9
    } ;

static yyconst flex_int16_t yy_base[483] =
    {   0,
        0,   38,   96,   12,   12,   13,   15,   16, 1028, 1444,
       32,   51,   20,  990, 1016,    0,  157,   18, 1007,  964,
      966,  961,  969, 1444,   25,   27,   27, 1444,  983, 1008,
     1008, 1004,  215,  253,    5,   32,   29,  974,   45,  962,
      996,   35,   38,   39,   40,   41,  134,   42,  136,  137,
      138,   75,  996,    0, 1444,  985,  984,  166,  964,  162,
     1444,    0,  987,  990, 1444, 1444,    0,  186,  165,  974,
      931,  933,  928,  936,  168,  943,  967,  928,  140,  930,
      935,   87,  167, 1444,  979,  974,  977,  968, 1444,  950,
     1444,  935,  934,  145,   52,   46,  148,  165,  922, 1444,

     1444,  152,  156,  155,  170,  173,  175,  182,  183,  185,
      211,  214,  222,  218,  221,  269,  957,  956,  291,    0,
     1444, 1444, 1444,  922, 1444,  937,  898,  195,  900,  905,
      907,  912,  906,  892,  890,  903,  893, 1444, 1444,  209,
      254,  251,  353,  248,  391,  354,  350,  351,  340,  355,
      341,  429,  339,  356,  344,  347,  360,  390,   43,  361,
      391,  395,  429, 1444,    0,    0,  280,  906,  900,  886,
      884,  897,  872,  876,  890,  867,  873,  878,  876,  866,
      381,  348,  382, 1444,  384, 1444,  389,  397,  491,  398,
     1444,  528,  418,  399,  420,  477,  478,  422,  421,  480,

      479,    0,  449, 1444,  884,  861,  867,  872,  870,  860,
      859,  892,  857,  866,  850,  862,  586,  493,  496,  494,
      484,  624, 1444,    0,  878,  876,  876,  834,  839,  841,
      832,  830,  199,  830,  490,  499,  486,  492,  488,  489,
      662,    0,  863,  828,  837,  821,  833,    0,  832,  859,
      700,  738,  776,  829, 1444,  431,  258,  437,  515, 1444,
      846,  844,  841,  817,  829,  809,  319,  815,  813,  478,
      809,  512,  528,  520,  525,  814, 1444,    0,  833,    0,
        0,    0,  803,  551,  808, 1444, 1444, 1444,  852,  383,
      521,  530,  539,  822,  829,  813,  793,  787,  802,  801,

      556,  793,  783,  785,  792,  787,  523,  545,  535, 1444,
        0,  795,    0,  561,  585, 1444,  555,  343,  581,  584,
      794,  811,  792,  773,  772, 1444,    0,  771,  783,  772,
      764,  552,  890,  558,    0,  623,  778,  784,  928,  966,
      583,  593,  594,  613,  792,  792,  771,  761,  746,  591,
     1444, 1004,    0,  778,    0,    0,  766,  776, 1444, 1444,
      620,  621,  626,  627,  653,  777,  769,  775, 1042, 1444,
        0,  772,  787,  767,  556,  577,  615,  649,  629,  762,
      753,  774, 1444,    0,  763, 1444,  773,  632,  659,  662,
      656,  654,  754,  742,  753,    0,  754,  729,  665,  688,

      667,  744,  742,  683,    0,  695,  692,  689,  715,  722,
      699,  711,  701,  666,  673,    0,  705, 1080,  704,  749,
      751,  753,  756,  663,  658,  618,  593,    0,    0, 1444,
      758, 1444,  760,  600,  588,  543,  483, 1444,  439,  386,
      247,  206,  167, 1444, 1118, 1127, 1136, 1145, 1154, 1158,
     1167, 1176, 1185, 1194, 1202, 1211, 1220, 1229, 1238, 1247,
     1256, 1265, 1273, 1282, 1290, 1298, 1306, 1314, 1323, 1331,
     1340, 1349, 1357, 1365, 1374, 1383, 1392, 1400, 1409, 1417,
     1426, 1435
    } ;

static yyconst flex_int16_t yy_def[483] =
    {   0,
      445,  445,  444,    3,  446,  446,  446,  446,  444,  444,
      444,  444,  447,  448,  449,  450,  444,  444,  450,  450,
      450,  450,  450,  444,  444,  444,  451,  444,  452,  444,
      444,  444,  453,  453,   34,   34,   34,   34,   34,  454,
      444,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,  444,  455,  456,  444,  457,  457,  444,  444,  447,
      444,  447,  444,  448,  444,  444,  450,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  450,  450,  450,  450,
      450,  444,  451,  444,  451,  444,  452,  444,  444,  444,
      444,   34,   34,   34,   34,   34,   34,   34,  454,  444,

      444,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,  444,  455,  455,  444,  458,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  450,  450,  450,  450,  450,  450,  444,  444,   34,
       34,   34,  453,   34,  453,   34,   34,   34,   34,   34,
       34,  453,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,  119,  444,  119,  459,  444,  444,  444,  444,
      444,  444,  444,  444,  450,  450,  450,  450,  450,  450,
       34,   34,   34,  444,   34,  444,   34,   34,  453,   34,
      444,  444,   34,   34,   34,   34,   34,   34,   34,   34,

       34,  460,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  450,  450,  450,  450,  450,  450,   34,   34,   34,
       34,  453,  444,  192,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,   34,   34,   34,   34,   34,   34,
      453,  461,  444,  444,  444,  444,  444,  462,  444,  450,
      450,  450,  450,  450,  444,   34,   34,   34,   34,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,   34,   34,   34,   34,  453,  444,  463,  444,  464,
      465,  466,  444,  444,  450,  444,  444,  444,  450,   34,
       34,   34,   34,  444,  444,  444,  444,  444,  444,  444,

      467,  444,  444,  444,  444,  444,   34,   34,   34,  444,
      468,  444,  469,  444,  450,  444,   34,   34,   34,   34,
      444,  444,  444,  444,  444,  444,  192,  444,  444,  444,
      444,   34,  453,   34,  470,  444,  444,  450,  450,  450,
       34,   34,   34,   34,  444,  444,  444,  444,  444,   34,
      444,  453,  471,  444,  472,  473,  444,  450,  444,  444,
       34,   34,   34,   34,   34,  444,  444,  444,  453,  444,
      474,  444,  444,  450,   34,   34,   34,   34,   34,  444,
      444,  444,  444,  475,  444,  444,  450,   34,   34,   34,
       34,   34,  444,  444,  444,  476,  444,  450,   34,   34,

       34,  444,  444,  444,  477,  444,  450,   34,  444,  478,
       34,  444,  444,  444,  444,  479,  444,  450,   34,  444,
      478,  478,  480,  444,  444,  444,  444,  481,  482,  444,
      444,  444,  480,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,    0,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444
    } ;

static yyconst flex_int16_t yy_nxt[1507] =
    {   0,
       10,   11,   12,   13,   10,   10,   14,   10,   10,   10,
       10,   15,   10,   52,   55,   55,   53,   55,   55,   75,
      444,   56,   56,   61,   57,   57,   82,   82,   82,   82,
       84,   92,   94,   58,   58,   10,   10,   10,   10,   17,
       12,   13,   18,   10,   14,   10,   10,   10,   10,   15,
       10,   59,   58,   58,   19,   92,   62,   95,   92,   96,
       76,   92,   98,   85,   92,   92,   92,   92,   92,   92,
       59,   92,   92,   10,   10,   10,  116,   82,   92,  117,
      143,   20,  105,  142,  103,  109,  198,  102,   82,   82,
      104,  106,  107,   21,   22,   23,   24,   25,   26,   27,

       24,   28,   29,   28,   28,   28,   30,   31,   32,   33,
       34,   35,   33,   36,   33,   37,   38,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   39,   33,
       33,   40,   41,   24,   33,   33,   42,   43,   44,   45,
       33,   33,   33,   46,   33,   47,   33,   48,   33,   49,
       33,   50,   33,   51,   33,   33,   33,   33,   68,   58,
       92,   69,   92,   92,   92,   61,   75,   58,   58,   75,
       84,   92,  141,   70,   92,  110,   59,  144,   92,  134,
      145,   92,   92,  112,  113,   59,  108,   68,   58,  115,
       69,   92,  111,  114,  135,  147,   92,  301,   62,   92,

       71,   92,   70,   85,  146,   59,  148,   76,   92,   92,
       76,   92,   72,   73,   74,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   91,  151,  149,   71,
      150,  152,  181,  153,  170,   92,  301,   92,  154,  155,
       92,   72,   73,   74,   92,  269,  270,   92,   92,  171,
       91,   91,   91,   91,   91,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,  156,  157,  158,  161,  182,
      116,   82,  160,  117,   92,  183,  162,   92,  185,   93,
       92,  203,  203,  159,   92,  443,  291,  204,   91,   91,
       91,  163,  163,  164,  163,  163,  163,  163,  163,  163,

      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  165,
      165,  165,  165,  165,  165,  165,  165,  165,  165,  165,
      165,  165,  165,  165,  165,  165,  165,  165,  165,  165,
      165,  165,  165,  184,  184,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,   92,   92,   92,  219,   92,
       92,  300,  342,   92,   92,  301,   92,   92,  188,  190,
       92,   92,   92,  194,  152,  195,   92,   92,  184,  184,
      184,  186,  186,  186,  186,  186,  186,  186,  186,  186,

      186,  186,  186,  152,  152,  189,  187,   92,   92,   92,
       92,  442,  193,  317,  196,   92,   92,   92,  199,  218,
      220,   92,  221,   92,   92,   92,  186,  186,  186,  191,
      192,  192,  191,  191,  191,  191,  191,  191,  191,  191,
      191,  197,  201,  200,   92,  222,   92,   92,   92,  236,
      203,  203,  290,  152,  152,  441,  204,   92,  292,  237,
      239,  235,  240,   92,  191,  191,  191,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  223,  223,  223,  223,  223,  223,  223,  223,  223,

      223,  223,  223,   92,   92,   92,   92,  256,  258,  257,
       92,  273,   92,  301,   92,   92,   92,  259,   92,   92,
       92,  238,   92,  304,  158,   92,  223,  223,  223,  224,
      224,  241,  272,  152,  152,  275,  293,  274,   92,  305,
      273,   92,  225,  226,  152,  276,   92,   92,  227,   92,
      307,   92,  314,  314,   92,  320,   92,  327,  327,  318,
      319,   92,  314,  314,  440,   92,  274,  308,  228,  229,
      230,   92,  309,  341,  334,  231,  332,  232,   92,  388,
      337,   92,   92,  233,   92,  234,  255,  255,  255,  255,
      255,  255,  255,  255,  255,  255,  255,  255,  338,  343,

      333,  344,  389,   92,  361,  439,  339,   92,  350,   92,
       92,  340,  340,  352,  362,  363,  301,   92,  437,   92,
       92,  255,  255,  255,  260,  260,  260,  260,  260,  260,
      260,  260,  260,  260,  260,  260,  354,  375,  390,   92,
      376,   92,  364,  377,  355,  369,   92,   92,  152,  356,
      356,  365,   92,   92,  392,   92,  436,  378,   92,  260,
      260,  260,  277,  277,  277,  277,  277,  277,  277,  277,
      277,  277,  277,  277,  379,   92,  399,  401,  400,   92,
       92,  408,   92,  435,  152,   92,  434,  391,   92,  409,
      409,   92,  411,   92,  427,  410,  426,  277,  277,  277,

      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  414,  418,   92,   92,  420,  420,  418,  418,
      425,  415,  421,  422,  422,   92,  429,  419,  424,  152,
       92,  429,  429,  417,  152,  286,  286,  286,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      420,  420,  422,  422,  422,  422,  421,  431,  431,  431,
      431,  431,  431,  413,  432,  412,  432,  407,  432,  406,
      404,  403,  402,  287,  287,  287,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  398,  397,
      395,  394,  393,  387,  386,  385,  382,  381,  380,  374,

      373,  372,  301,  301,  368,  367,  366,  358,  357,  304,
      349,  288,  288,  288,  310,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  310,  310,  348,  301,  301,  301,
      347,  346,  345,  336,  331,  330,  329,  328,  301,  325,
      324,  301,  301,  323,  322,  321,  315,  313,  312,  310,
      310,  310,  316,  316,  316,  316,  316,  316,  316,  316,
      316,  316,  316,  316,  306,  303,  302,  299,  298,  297,
      296,  295,  294,  289,  285,  284,  283,  282,  281,  280,
      279,  271,  268,  267,  266,  265,  264,  316,  316,  316,
      351,  351,  351,  351,  351,  351,  351,  351,  351,  351,

      351,  351,  263,  262,  261,  254,  253,  252,  251,  250,
      249,  248,  247,  246,  245,  244,  243,  217,  216,  215,
      214,  213,  212,  211,  210,  351,  351,  351,  359,  359,
      359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
      209,  208,  207,  206,  205,  180,  179,  178,  177,  176,
      175,  174,  173,  172,  169,  168,  167,  118,  118,  100,
      140,   92,   90,  359,  359,  359,  360,  360,  360,  360,
      360,  360,  360,  360,  360,  360,  360,  360,  139,  444,
      138,  444,  137,  136,  133,  132,  131,  130,  129,  128,
      127,  126,  444,  125,  124,  123,  122,  118,  101,  100,

       97,  360,  360,  360,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,   90,   89,   88,   87,
       81,   80,   79,   78,   77,   66,   64,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  370,
      370,  370,  383,  383,  383,  383,  383,  383,  383,  383,
      383,  383,  383,  383,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  383,  383,  383,
      430,  430,  430,  430,  430,  430,  430,  430,  430,  430,
      430,  430,  444,  444,  444,  444,  444,  444,  444,  444,

      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  430,  430,  430,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   67,   67,  444,   67,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   92,   92,   92,   92,   92,
       92,   92,   92,   92,   99,   99,   99,   99,   99,   99,

       99,  444,   99,  119,  444,  444,  444,  444,  444,  444,
      119,  120,  120,  444,  120,  444,  120,  120,  120,  120,
      121,  121,  121,  121,  121,  121,  121,  121,  121,  166,
      166,  444,  166,  444,  166,  166,  166,  166,  202,  202,
      444,  202,  444,  202,  202,  202,  202,  242,  242,  444,
      242,  444,  242,  242,  242,  242,  278,  278,  444,  278,
      444,  278,  278,  278,  278,  255,  255,  255,  255,  255,
      444,  444,  255,  311,  311,  444,  311,  444,  311,  311,
      311,  311,  286,  286,  286,  286,  286,  444,  444,  286,
      287,  287,  287,  287,  287,  444,  444,  287,  288,  288,

      288,  288,  288,  444,  444,  288,  326,  326,  326,  326,
      326,  444,  444,  326,  335,  335,  444,  335,  444,  335,
      335,  335,  335,  316,  316,  316,  316,  316,  444,  444,
      316,  353,  353,  444,  353,  444,  353,  353,  353,  353,
      371,  371,  444,  371,  444,  371,  371,  371,  371,  359,
      359,  359,  359,  359,  444,  444,  359,  360,  360,  360,
      360,  360,  444,  444,  360,  384,  384,  444,  384,  444,
      384,  384,  384,  384,  396,  396,  444,  396,  444,  396,
      396,  396,  396,  405,  405,  444,  405,  444,  405,  405,
      405,  405,  416,  416,  444,  416,  444,  416,  416,  416,

      416,  423,  423,  444,  444,  444,  423,  444,  423,  428,
      428,  444,  428,  444,  428,  428,  428,  428,  433,  433,
      433,  444,  433,  433,  444,  433,  438,  438,  444,  438,
      444,  438,  438,  438,  438,  430,  430,  430,  430,  430,
      444,  444,  430,    9,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,

      444,  444,  444,  444,  444,  444
    } ;

static yyconst flex_int16_t yy_chk[1507] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    4,    5,    6,    4,    7,    8,   18,
        0,    5,    6,   13,    7,    8,   25,   25,   26,   26,
       27,   35,   35,   11,   11,    1,    1,    1,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,   11,   12,   12,    2,   37,   13,   36,   36,   37,
       18,   42,   39,   27,   43,   44,   45,   46,   48,  159,
       12,   39,   96,    2,    2,    2,   52,   52,   95,   52,
       96,    2,   44,   95,   43,   48,  159,   42,   82,   82,
       43,   45,   46,    2,    2,    2,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,   17,   17,
       47,   17,   49,   50,   51,   60,   69,   58,   58,   75,
       83,   94,   94,   17,   97,   49,   17,   97,  102,   79,
       98,  104,  103,   50,   50,   58,   47,   68,   68,   51,
       68,   98,   49,   50,   79,  103,  105,  443,   60,  106,

       17,  107,   68,   83,  102,   68,  104,   69,  108,  109,
       75,  110,   17,   17,   17,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,  107,  105,   68,
      106,  107,  140,  108,  128,  140,  442,  111,  109,  110,
      112,   68,   68,   68,  114,  233,  233,  115,  113,  128,
       33,   33,   33,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,  111,  112,  113,  115,  141,
      116,  116,  114,  116,  144,  142,  115,  142,  144,   34,
      141,  167,  167,  113,  257,  441,  257,  167,   34,   34,
       34,  119,  119,  119,  119,  119,  119,  119,  119,  119,

      119,  119,  119,  119,  119,  119,  119,  119,  119,  119,
      119,  119,  119,  119,  119,  119,  119,  119,  119,  119,
      119,  119,  119,  119,  119,  119,  119,  119,  119,  119,
      119,  119,  119,  119,  119,  119,  119,  119,  119,  119,
      119,  119,  119,  119,  119,  119,  119,  119,  119,  119,
      119,  119,  119,  143,  143,  143,  143,  143,  143,  143,
      143,  143,  143,  143,  143,  153,  149,  151,  182,  318,
      155,  267,  318,  156,  182,  267,  147,  148,  149,  151,
      146,  150,  154,  155,  153,  156,  157,  160,  143,  143,
      143,  145,  145,  145,  145,  145,  145,  145,  145,  145,

      145,  145,  145,  146,  147,  150,  148,  181,  183,  290,
      185,  440,  154,  290,  157,  187,  158,  161,  160,  181,
      183,  162,  185,  188,  190,  194,  145,  145,  145,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  158,  162,  161,  193,  187,  195,  199,  198,  194,
      203,  203,  256,  188,  190,  439,  203,  256,  258,  195,
      198,  193,  199,  258,  152,  152,  152,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  189,  189,  189,  189,  189,  189,  189,  189,  189,

      189,  189,  189,  196,  197,  201,  200,  218,  220,  219,
      221,  236,  237,  437,  239,  240,  235,  221,  238,  218,
      220,  197,  219,  270,  201,  236,  189,  189,  189,  192,
      192,  200,  235,  196,  238,  237,  259,  236,  272,  270,
      273,  259,  192,  192,  239,  240,  274,  291,  192,  307,
      272,  275,  284,  284,  273,  293,  292,  301,  301,  291,
      292,  309,  314,  314,  436,  293,  273,  274,  192,  192,
      192,  308,  275,  317,  309,  192,  307,  192,  332,  375,
      314,  317,  375,  192,  334,  192,  217,  217,  217,  217,
      217,  217,  217,  217,  217,  217,  217,  217,  315,  319,

      308,  320,  376,  376,  341,  435,  315,  319,  332,  341,
      320,  315,  315,  334,  342,  343,  434,  350,  427,  342,
      343,  217,  217,  217,  222,  222,  222,  222,  222,  222,
      222,  222,  222,  222,  222,  222,  336,  361,  377,  344,
      362,  377,  344,  363,  336,  350,  361,  362,  388,  336,
      336,  344,  363,  364,  379,  379,  426,  364,  388,  222,
      222,  222,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  365,  378,  389,  391,  390,  365,
      392,  399,  391,  425,  392,  389,  424,  378,  390,  400,
      400,  399,  401,  401,  415,  400,  414,  241,  241,  241,

      251,  251,  251,  251,  251,  251,  251,  251,  251,  251,
      251,  251,  404,  407,  400,  408,  409,  409,  407,  407,
      413,  404,  409,  410,  410,  411,  417,  408,  412,  411,
      419,  417,  417,  406,  419,  251,  251,  251,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      420,  420,  421,  421,  422,  422,  420,  423,  423,  431,
      431,  433,  433,  403,  423,  402,  431,  398,  433,  397,
      395,  394,  393,  252,  252,  252,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  387,  385,
      382,  381,  380,  374,  373,  372,  368,  367,  366,  358,

      357,  354,  349,  348,  347,  346,  345,  338,  337,  331,
      330,  253,  253,  253,  276,  276,  276,  276,  276,  276,
      276,  276,  276,  276,  276,  276,  329,  328,  325,  324,
      323,  322,  321,  312,  306,  305,  304,  303,  302,  300,
      299,  298,  297,  296,  295,  294,  285,  283,  279,  276,
      276,  276,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  289,  289,  271,  269,  268,  266,  265,  264,
      263,  262,  261,  254,  250,  249,  247,  246,  245,  244,
      243,  234,  232,  231,  230,  229,  228,  289,  289,  289,
      333,  333,  333,  333,  333,  333,  333,  333,  333,  333,

      333,  333,  227,  226,  225,  216,  215,  214,  213,  212,
      211,  210,  209,  208,  207,  206,  205,  180,  179,  178,
      177,  176,  175,  174,  173,  333,  333,  333,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      172,  171,  170,  169,  168,  137,  136,  135,  134,  133,
      132,  131,  130,  129,  127,  126,  124,  118,  117,   99,
       93,   92,   90,  339,  339,  339,  340,  340,  340,  340,
      340,  340,  340,  340,  340,  340,  340,  340,   88,   87,
       86,   85,   81,   80,   78,   77,   76,   74,   73,   72,
       71,   70,   64,   63,   59,   57,   56,   53,   41,   40,

       38,  340,  340,  340,  352,  352,  352,  352,  352,  352,
      352,  352,  352,  352,  352,  352,   32,   31,   30,   29,
       23,   22,   21,   20,   19,   15,   14,    9,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  352,
      352,  352,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  369,  369,  369,
      418,  418,  418,  418,  418,  418,  418,  418,  418,  418,
      418,  418,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  418,  418,  418,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  449,  449,  449,  449,  449,  449,
      449,  449,  449,  450,  450,    0,  450,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  453,  453,  453,  453,  453,
      453,  453,  453,  453,  454,  454,  454,  454,  454,  454,

      454,    0,  454,  455,    0,    0,    0,    0,    0,    0,
      455,  456,  456,    0,  456,    0,  456,  456,  456,  456,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  458,
      458,    0,  458,    0,  458,  458,  458,  458,  459,  459,
        0,  459,    0,  459,  459,  459,  459,  460,  460,    0,
      460,    0,  460,  460,  460,  460,  461,  461,    0,  461,
        0,  461,  461,  461,  461,  462,  462,  462,  462,  462,
        0,    0,  462,  463,  463,    0,  463,    0,  463,  463,
      463,  463,  464,  464,  464,  464,  464,    0,    0,  464,
      465,  465,  465,  465,  465,    0,    0,  465,  466,  466,

      466,  466,  466,    0,    0,  466,  467,  467,  467,  467,
      467,    0,    0,  467,  468,  468,    0,  468,    0,  468,
      468,  468,  468,  469,  469,  469,  469,  469,    0,    0,
      469,  470,  470,    0,  470,    0,  470,  470,  470,  470,
      471,  471,    0,  471,    0,  471,  471,  471,  471,  472,
      472,  472,  472,  472,    0,    0,  472,  473,  473,  473,
      473,  473,    0,    0,  473,  474,  474,    0,  474,    0,
      474,  474,  474,  474,  475,  475,    0,  475,    0,  475,
      475,  475,  475,  476,  476,    0,  476,    0,  476,  476,
      476,  476,  477,  477,    0,  477,    0,  477,  477,  477,

      477,  478,  478,    0,    0,    0,  478,    0,  478,  479,
      479,    0,  479,    0,  479,  479,  479,  479,  480,  480,
      480,    0,  480,  480,    0,  480,  481,  481,    0,  481,
        0,  481,  481,  481,  481,  482,  482,  482,  482,  482,
        0,    0,  482,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,

      444,  444,  444,  444,  444,  444
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* -*- indented-text -*- */
/* Process source files and output type information.
   Copyright (C) 2002, 2003, 2004, 2005, 2007 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */
#line 22 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
#include "bconfig.h"
#include "system.h"

#define malloc xmalloc
#define realloc xrealloc

#include "gengtype.h"

#define YY_DECL int yylex (const char **yylval)
#define yyterminate() return EOF_TOKEN

struct fileloc lexer_line;
int lexer_toplevel_done;

static void 
update_lineno (const char *l, size_t len)
{
  while (len-- > 0)
    if (*l++ == '\n')
      lexer_line.line++;
}


#line 984 "gengtype-lex.c"

#define INITIAL 0
#define in_struct 1
#define in_struct_comment 2
#define in_comment 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		unsigned n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 56 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"

  /* Do this on entry to yylex():  */
  *yylval = 0;
  if (lexer_toplevel_done)
    {
      BEGIN(INITIAL);
      lexer_toplevel_done = 0;
    }

  /* Things we look for in skipping mode: */
#line 1181 "gengtype-lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 445 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 444 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 67 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return TYPEDEF;
}
	YY_BREAK
case 2:
/* rule 2 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 71 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return STRUCT;
}
	YY_BREAK
case 3:
/* rule 3 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 75 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return UNION;
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 79 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return EXTERN;
}
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 83 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return STATIC;
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 88 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return DEFVEC_OP;
}
	YY_BREAK
case 7:
/* rule 7 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 92 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return DEFVEC_I;
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 96 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  BEGIN(in_struct);
  return DEFVEC_ALLOC;
}
	YY_BREAK


case 9:
YY_RULE_SETUP
#line 104 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ BEGIN(in_struct_comment); }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 106 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ update_lineno (yytext, yyleng); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 107 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ lexer_line.line++; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 109 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* don't care */
	YY_BREAK
case 13:
/* rule 13 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 110 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return GTY_TOKEN; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 111 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return VEC_TOKEN; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 112 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return UNION; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 113 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return STRUCT; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 114 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return ENUM; }
	YY_BREAK
case 18:
/* rule 18 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 115 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return PTR_ALIAS; }
	YY_BREAK
case 19:
/* rule 19 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 10;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 116 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return NESTED_PTR; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 117 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return NUM; }
	YY_BREAK
case 21:
/* rule 21 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 118 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  *yylval = xmemdup (yytext, yyleng, yyleng+1);
  return PARAM_IS;
}
	YY_BREAK
case 22:
/* rule 22 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
#line 124 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 124 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  size_t len;

  for (len = yyleng; ISSPACE (yytext[len-1]); len--)
    ;

  *yylval = xmemdup (yytext, len, len+1);
  update_lineno (yytext, yyleng);
  return SCALAR;
}
	YY_BREAK
case 24:
/* rule 24 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 136 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  *yylval = xmemdup (yytext, yyleng, yyleng+1);
  return ID;
}
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 141 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  *yylval = xmemdup (yytext+1, yyleng-2, yyleng-1);
  return STRING;
}
	YY_BREAK
/* This "terminal" avoids having to parse integer constant expressions.  */
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 146 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  *yylval = xmemdup (yytext+1, yyleng-2, yyleng-1);
  return ARRAY;
}
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 150 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  *yylval = xmemdup (yytext+1, yyleng-2, yyleng);
  return CHAR;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 155 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return ELLIPSIS; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 156 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ return yytext[0]; }
	YY_BREAK
/* ignore pp-directives */
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 159 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{lexer_line.line++;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 161 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  error_at_line (&lexer_line, "unexpected character `%s'", yytext);
}
	YY_BREAK

case 32:
YY_RULE_SETUP
#line 166 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ BEGIN(in_comment); }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 167 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ lexer_line.line++; }
	YY_BREAK
case 34:
#line 169 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
case 35:
/* rule 35 can match eol */
#line 170 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 170 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 171 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ update_lineno (yytext, yyleng); }
	YY_BREAK
case 38:
/* rule 38 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 172 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK

case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 175 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ lexer_line.line++; }
	YY_BREAK
case 40:
#line 177 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
case 41:
YY_RULE_SETUP
#line 177 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK
case 42:
/* rule 42 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 178 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK

case 43:
YY_RULE_SETUP
#line 180 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ BEGIN(INITIAL); } 
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 181 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{ BEGIN(in_struct); }
	YY_BREAK
case 45:
#line 184 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
case 46:
YY_RULE_SETUP
#line 184 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  error_at_line (&lexer_line, 
		 "unterminated comment or string; unexpected EOF");
}
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 189 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
/* do nothing */
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
#line 190 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
{
  error_at_line (&lexer_line, "stray GTY marker");
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 194 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1651 "gengtype-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(in_struct):
case YY_STATE_EOF(in_struct_comment):
case YY_STATE_EOF(in_comment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 445 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 445 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 444);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 194 "/gcc-4.3/gcc-4.3.1/gcc-4.3.1/gcc/gengtype-lex.l"



void
yybegin (const char *fname)
{
  yyin = fopen (fname, "r");
  if (yyin == NULL)
    {
      perror (fname);
      exit (1);
    }
  lexer_line.file = fname;
  lexer_line.line = 1;
}

void
yyend (void)
{
  fclose (yyin);
}

